@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset: 4 -*-
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  * vim: tabstop=4 shiftwidth=4 expandtab
  */
 
@@ -236,10 +236,16 @@ void gi_marshalling_tests_time_t_inout (time_t *time_t_);
 
 GType gi_marshalling_tests_gtype_return (void);
 
+GType gi_marshalling_tests_gtype_string_return (void);
+
 void gi_marshalling_tests_gtype_in (GType gtype);
 
+void gi_marshalling_tests_gtype_string_in (GType gtype);
+
 void gi_marshalling_tests_gtype_out (GType *gtype);
 
+void gi_marshalling_tests_gtype_string_out (GType *gtype);
+
 void gi_marshalling_tests_gtype_inout (GType *gtype);
 
 
@@ -297,7 +303,7 @@ typedef enum
 GType gi_marshalling_tests_genum_get_type (void) G_GNUC_CONST;
 #define GI_MARSHALLING_TESTS_TYPE_GENUM (gi_marshalling_tests_genum_get_type ())
 
-GIMarshallingTestsEnum gi_marshalling_tests_genum_returnv (void);
+GIMarshallingTestsGEnum gi_marshalling_tests_genum_returnv (void);
 
 void gi_marshalling_tests_genum_in (GIMarshallingTestsGEnum enum_);
 
@@ -392,9 +398,12 @@ void gi_marshalling_tests_array_out_etc (gint first, gint **ints, gint *length,
 void gi_marshalling_tests_array_inout (gint **ints, gint *length);
 void gi_marshalling_tests_array_inout_etc (gint first, gint **ints, gint *length, gint last, gint *sum);
 
+void gi_marshalling_tests_array_in_nonzero_nonlen (gint first, const guint8 *chars);
+
 /* Zero-terminated */
 
 gchar **gi_marshalling_tests_array_zero_terminated_return (void);
+gchar **gi_marshalling_tests_array_zero_terminated_return_null (void);
 GIMarshallingTestsBoxedStruct **gi_marshalling_tests_array_zero_terminated_return_struct (void);
 
 void gi_marshalling_tests_array_zero_terminated_in (gchar **utf8s);
@@ -403,17 +412,23 @@ void gi_marshalling_tests_array_zero_terminated_out (gchar ***utf8s);
 
 void gi_marshalling_tests_array_zero_terminated_inout (gchar ***utf8s);
 
-GVariant **gi_marshalling_tests_array_gvariant_in (GVariant **variants);
+GVariant **gi_marshalling_tests_array_gvariant_none_in (GVariant **variants);
+
+GVariant **gi_marshalling_tests_array_gvariant_container_in (GVariant **variants);
+
+GVariant **gi_marshalling_tests_array_gvariant_full_in (GVariant **variants);
 
 
 /* GArray */
 
 GArray *gi_marshalling_tests_garray_int_none_return (void);
+GArray *gi_marshalling_tests_garray_uint64_none_return (void);
 GArray *gi_marshalling_tests_garray_utf8_none_return (void);
 GArray *gi_marshalling_tests_garray_utf8_container_return (void);
 GArray *gi_marshalling_tests_garray_utf8_full_return (void);
 
 void gi_marshalling_tests_garray_int_none_in (GArray *array_);
+void gi_marshalling_tests_garray_uint64_none_in (GArray *array_);
 void gi_marshalling_tests_garray_utf8_none_in (GArray *array_);
 
 void gi_marshalling_tests_garray_utf8_none_out (GArray **array_);
@@ -454,11 +469,13 @@ void gi_marshalling_tests_gstrv_inout (GStrv *g_strv);
 /* GList */
 
 GList *gi_marshalling_tests_glist_int_none_return (void);
+GList *gi_marshalling_tests_glist_uint32_none_return (void);
 GList *gi_marshalling_tests_glist_utf8_none_return (void);
 GList *gi_marshalling_tests_glist_utf8_container_return (void);
 GList *gi_marshalling_tests_glist_utf8_full_return (void);
 
 void gi_marshalling_tests_glist_int_none_in (GList *list);
+void gi_marshalling_tests_glist_uint32_none_in (GList *list);
 void gi_marshalling_tests_glist_utf8_none_in (GList *list);
 
 void gi_marshalling_tests_glist_utf8_none_out (GList **list);
@@ -515,19 +532,80 @@ void gi_marshalling_tests_ghashtable_utf8_full_inout (GHashTable **hash_table);
 GValue *gi_marshalling_tests_gvalue_return (void);
 
 void gi_marshalling_tests_gvalue_in (GValue *value);
+void gi_marshalling_tests_gvalue_int64_in (GValue *value);
+void gi_marshalling_tests_gvalue_in_with_type (GValue *value, GType type);
 
 void gi_marshalling_tests_gvalue_in_enum (GValue *value);
 
 void gi_marshalling_tests_gvalue_out (GValue **value);
+void gi_marshalling_tests_gvalue_int64_out (GValue **value);
+void gi_marshalling_tests_gvalue_out_caller_allocates (GValue *value);
 
 void gi_marshalling_tests_gvalue_inout (GValue **value);
 
+void gi_marshalling_tests_gvalue_flat_array (guint         n_values,
+                                             const GValue *values);
+
+GValue *gi_marshalling_tests_return_gvalue_flat_array (void);
+
+GValue *gi_marshalling_tests_gvalue_flat_array_round_trip (const GValue one,
+                                                           const GValue two,
+                                                           const GValue three);
 
 /* GClosure */
 
 void gi_marshalling_tests_gclosure_in (GClosure *closure);
 GClosure *gi_marshalling_tests_gclosure_return (void);
 
+/* Callback return values */
+
+/**
+ * GIMarshallingTestsCallbackReturnValueOnly:
+ */
+typedef glong (* GIMarshallingTestsCallbackReturnValueOnly) ();
+
+glong gi_marshalling_tests_callback_return_value_only (GIMarshallingTestsCallbackReturnValueOnly callback);
+
+/**
+ * GIMarshallingTestsCallbackOneOutParameter:
+ * @a: (out):
+ */
+typedef void (* GIMarshallingTestsCallbackOneOutParameter) (gfloat *a);
+
+void gi_marshalling_tests_callback_one_out_parameter (GIMarshallingTestsCallbackOneOutParameter  callback,
+                                                      gfloat                                    *a);
+
+/**
+ * GIMarshallingTestsCallbackMultipleOutParameters:
+ * @a: (out):
+ * @b: (out):
+ */
+typedef void (* GIMarshallingTestsCallbackMultipleOutParameters) (gfloat *a, gfloat *b);
+
+void gi_marshalling_tests_callback_multiple_out_parameters (GIMarshallingTestsCallbackMultipleOutParameters  callback,
+                                                            gfloat                                          *a,
+                                                            gfloat                                          *b);
+
+/**
+ * GIMarshallingTestsCallbackReturnValueAndOneOutParameter:
+ * @a: (out):
+ */
+typedef glong (* GIMarshallingTestsCallbackReturnValueAndOneOutParameter) (glong *a);
+
+glong gi_marshalling_tests_callback_return_value_and_one_out_parameter (GIMarshallingTestsCallbackReturnValueAndOneOutParameter  callback,
+                                                                        glong                                                   *a);
+
+/**
+ * GIMarshallingTestsCallbackReturnValueAndMultipleOutParameters:
+ * @a: (out):
+ * @b: (out):
+ */
+typedef glong (* GIMarshallingTestsCallbackReturnValueAndMultipleOutParameters) (glong *a, glong *b);
+
+glong gi_marshalling_tests_callback_return_value_and_multiple_out_parameters (GIMarshallingTestsCallbackReturnValueAndMultipleOutParameters  callback,
+                                                                              glong                                                         *a,
+                                                                              glong                                                         *b);
+
 /* Pointer */
 
 gpointer gi_marshalling_tests_pointer_in_return (gpointer pointer);
@@ -598,7 +676,7 @@ void gi_marshalling_tests_union_inout (GIMarshallingTestsUnion **union_);
 
 void gi_marshalling_tests_union_method (GIMarshallingTestsUnion *union_);
 
-/* Object */
+ /* Object */
 
 #define GI_MARSHALLING_TESTS_TYPE_OBJECT             (gi_marshalling_tests_object_get_type ())
 #define GI_MARSHALLING_TESTS_OBJECT(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GI_MARSHALLING_TESTS_TYPE_OBJECT, GIMarshallingTestsObject))
@@ -610,6 +688,8 @@ void gi_marshalling_tests_union_method (GIMarshallingTestsUnion *union_);
 typedef struct _GIMarshallingTestsObjectClass GIMarshallingTestsObjectClass;
 typedef struct _GIMarshallingTestsObject GIMarshallingTestsObject;
 
+typedef int (* GIMarshallingTestsCallbackIntInt) (int val, void *user_data);
+
 struct _GIMarshallingTestsObjectClass
 {
 	GObjectClass parent_class;
@@ -631,6 +711,60 @@ struct _GIMarshallingTestsObjectClass
      * @in: (in):
      */
     void (* method_with_default_implementation) (GIMarshallingTestsObject *self, gint8 in);
+
+    /**
+     * GIMarshallingTestsObjectClass::method_deep_hierarchy:
+     * @in: (in):
+     */
+    void (* method_deep_hierarchy) (GIMarshallingTestsObject *self, gint8 in);
+
+    void (* vfunc_with_callback) (GIMarshallingTestsObject *self,
+                                  GIMarshallingTestsCallbackIntInt callback,
+                                  void *callback_data);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_return_value_only:
+     */
+    glong (* vfunc_return_value_only) (GIMarshallingTestsObject *self);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_one_out_parameter:
+     * @a: (out):
+     */
+    void  (* vfunc_one_out_parameter) (GIMarshallingTestsObject *self, gfloat *a);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_multiple_out_parameters:
+     * @a: (out):
+     * @b: (out):
+     */
+    void  (* vfunc_multiple_out_parameters) (GIMarshallingTestsObject *self, gfloat *a, gfloat *b);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_caller_allocated_out_parameter:
+     * @a: (out):
+     */
+    void  (* vfunc_caller_allocated_out_parameter) (GIMarshallingTestsObject *self, GValue *a);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_return_value_and_one_out_parameter:
+     * @a: (out):
+     */
+    glong (* vfunc_return_value_and_one_out_parameter) (GIMarshallingTestsObject *self, glong *a);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_return_value_and_multiple_out_parameters:
+     * @a: (out):
+     * @b: (out):
+     */
+    glong (* vfunc_return_value_and_multiple_out_parameters) (GIMarshallingTestsObject *self, glong *a, glong *b);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_meth_with_err:
+     * @x:
+     * @error: A #GError
+     */
+    gboolean (*vfunc_meth_with_err) (GIMarshallingTestsObject *object, gint x, GError **error);
 };
 
 struct _GIMarshallingTestsObject
@@ -654,7 +788,15 @@ const gint *gi_marshalling_tests_object_method_array_return (GIMarshallingTestsO
 void gi_marshalling_tests_object_method_int8_in (GIMarshallingTestsObject *object, gint8 in);
 void gi_marshalling_tests_object_method_int8_out (GIMarshallingTestsObject *object, gint8 *out);
 void gi_marshalling_tests_object_method_with_default_implementation (GIMarshallingTestsObject *object, gint8 in);
+void gi_marshalling_tests_object_method_variant_array_in (GIMarshallingTestsObject *object, GVariant **in, gsize n_in);
 
+glong gi_marshalling_tests_object_vfunc_return_value_only (GIMarshallingTestsObject *self);
+void gi_marshalling_tests_object_vfunc_one_out_parameter (GIMarshallingTestsObject *self, gfloat *a);
+void gi_marshalling_tests_object_vfunc_multiple_out_parameters (GIMarshallingTestsObject *self, gfloat *a, gfloat *b);
+void gi_marshalling_tests_object_vfunc_caller_allocated_out_parameter (GIMarshallingTestsObject *self, GValue *a);
+glong gi_marshalling_tests_object_vfunc_return_value_and_one_out_parameter (GIMarshallingTestsObject *self, glong *a);
+glong gi_marshalling_tests_object_vfunc_return_value_and_multiple_out_parameters (GIMarshallingTestsObject *self, glong *a, glong *b);
+gboolean gi_marshalling_tests_object_vfunc_meth_with_error (GIMarshallingTestsObject *object, gint x, GError **error);
 
 GIMarshallingTestsObject *gi_marshalling_tests_object_none_return (void);
 GIMarshallingTestsObject *gi_marshalling_tests_object_full_return (void);
@@ -672,6 +814,11 @@ void gi_marshalling_tests_object_inout_same (GIMarshallingTestsObject **object);
 void gi_marshalling_tests_object_int8_in (GIMarshallingTestsObject *object, gint8 in);
 void gi_marshalling_tests_object_int8_out (GIMarshallingTestsObject *object, gint8 *out);
 
+void gi_marshalling_tests_object_vfunc_with_callback (GIMarshallingTestsObject *object,
+                                                      GIMarshallingTestsCallbackIntInt callback,
+                                                      void *callback_data);
+void gi_marshalling_tests_object_call_vfunc_with_callback (GIMarshallingTestsObject *object);
+
 #define GI_MARSHALLING_TESTS_TYPE_SUB_OBJECT             (gi_marshalling_tests_sub_object_get_type ())
 #define GI_MARSHALLING_TESTS_SUB_OBJECT(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GI_MARSHALLING_TESTS_TYPE_SUB_OBJECT, GIMarshallingTestsSubObject))
 #define GI_MARSHALLING_TESTS_SUB_OBJECT_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GI_MARSHALLING_TESTS_TYPE_SUB_OBJECT, GIMarshallingTestsSubObjectClass))
@@ -697,6 +844,28 @@ GType gi_marshalling_tests_sub_object_get_type (void) G_GNUC_CONST;
 void gi_marshalling_tests_sub_object_sub_method (GIMarshallingTestsSubObject *object);
 void gi_marshalling_tests_sub_object_overwritten_method (GIMarshallingTestsSubObject *object);
 
+#define GI_MARSHALLING_TESTS_TYPE_SUB_SUB_OBJECT             (gi_marshalling_tests_sub_sub_object_get_type ())
+#define GI_MARSHALLING_TESTS_SUB_SUB_OBJECT(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GI_MARSHALLING_TESTS_TYPE_SUB_SUB_OBJECT, GIMarshallingTestsSubSubObject))
+#define GI_MARSHALLING_TESTS_SUB_SUB_OBJECT_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GI_MARSHALLING_TESTS_TYPE_SUB_SUB_OBJECT, GIMarshallingTestsSubSubObjectClass))
+#define GI_MARSHALLING_TESTS_IS_SUB_SUB_OBJECT(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GI_MARSHALLING_TESTS_TYPE_SUB_SUB_OBJECT))
+#define GI_MARSHALLING_TESTS_IS_SUB_SUB_OBJECT_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GI_MARSHALLING_TESTS_TYPE_SUB_SUB_OBJECT))
+#define GI_MARSHALLING_TESTS_SUB_SUB_OBJECT_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GI_MARSHALLING_TESTS_TYPE_SUB_SUB_OBJECT, GIMarshallingTestsSubSubObjectClass))
+
+typedef struct _GIMarshallingTestsSubSubObjectClass GIMarshallingTestsSubSubObjectClass;
+typedef struct _GIMarshallingTestsSubSubObject GIMarshallingTestsSubSubObject;
+
+struct _GIMarshallingTestsSubSubObjectClass
+{
+	GIMarshallingTestsSubObjectClass parent_class;
+};
+
+struct _GIMarshallingTestsSubSubObject
+{
+	GIMarshallingTestsSubObject parent_instance;
+};
+
+GType gi_marshalling_tests_sub_sub_object_get_type (void) G_GNUC_CONST;
+
 /* Interfaces */
 
 #define GI_MARSHALLING_TESTS_TYPE_INTERFACE              (gi_marshalling_tests_interface_get_type ())
@@ -729,7 +898,7 @@ void gi_marshalling_tests_test_interface_test_int8_in (GIMarshallingTestsInterfa
 #define GI_MARSHALLING_TESTS_TYPE_INTERFACE2              (gi_marshalling_tests_interface2_get_type ())
 #define GI_MARSHALLING_TESTS_INTERFACE2(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GI_MARSHALLING_TESTS_TYPE_INTERFACE2, GIMarshallingTestsInterface2))
 #define GI_MARSHALLING_TESTS_IS_INTERFACE2(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), GI_MARSHALLING_TESTS_TYPE_INTERFACE2))
-#define GI_MARSHALLING_TESTS_INTERFACE2_GET_IFACE(obj)    (G_TYPE_INSTANCE_GET_INTERFACE2 ((obj), GI_MARSHALLING_TESTS_TYPE_INTERFACE2, GIMarshallingTestsInterface2Iface))
+#define GI_MARSHALLING_TESTS_INTERFACE2_GET_IFACE(obj)    (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GI_MARSHALLING_TESTS_TYPE_INTERFACE2, GIMarshallingTestsInterface2Iface))
 
 typedef struct _GIMarshallingTestsInterface2 GIMarshallingTestsInterface2;
 typedef struct _GIMarshallingTestsInterface2Iface GIMarshallingTestsInterface2Iface;
@@ -746,6 +915,29 @@ struct _GIMarshallingTestsInterface2Iface {
 
 GType gi_marshalling_tests_interface2_get_type (void) G_GNUC_CONST;
 
+/* GIMarshallingTestsInterface3 tests passing arrays of variants from C to @lang */
+
+#define GI_MARSHALLING_TESTS_TYPE_INTERFACE3              (gi_marshalling_tests_interface3_get_type ())
+#define GI_MARSHALLING_TESTS_INTERFACE3(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GI_MARSHALLING_TESTS_TYPE_INTERFACE3, GIMarshallingTestsInterface3))
+#define GI_MARSHALLING_TESTS_IS_INTERFACE3(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), GI_MARSHALLING_TESTS_TYPE_INTERFACE3))
+#define GI_MARSHALLING_TESTS_INTERFACE3_GET_IFACE(obj)    (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GI_MARSHALLING_TESTS_TYPE_INTERFACE3, GIMarshallingTestsInterface3Iface))
+
+typedef struct _GIMarshallingTestsInterface3 GIMarshallingTestsInterface3;
+typedef struct _GIMarshallingTestsInterface3Iface GIMarshallingTestsInterface3Iface;
+
+struct _GIMarshallingTestsInterface3Iface {
+    GTypeInterface base_iface;
+ 
+    /**
+     * GIMarshallingTestsInterface3::test_variant_array_in:
+     * @in: (in) (array length=n_in):
+     */
+    void (* test_variant_array_in) (GIMarshallingTestsInterface3 *self, GVariant **in, gsize n_in);
+};
+
+GType gi_marshalling_tests_interface3_get_type (void) G_GNUC_CONST;
+
+void gi_marshalling_tests_interface3_test_variant_array_in (GIMarshallingTestsInterface3 *self, GVariant **in, gsize n_in);
 
 /* Multiple output arguments */
 
@@ -760,9 +952,17 @@ gint gi_marshalling_tests_int_return_out (gint *int_);
 #define GI_MARSHALLING_TESTS_CONSTANT_GERROR_DOMAIN "gi-marshalling-tests-gerror-domain"
 #define GI_MARSHALLING_TESTS_CONSTANT_GERROR_CODE 5
 #define GI_MARSHALLING_TESTS_CONSTANT_GERROR_MESSAGE "gi-marshalling-tests-gerror-message"
+#define GI_MARSHALLING_TESTS_CONSTANT_GERROR_DEBUG_MESSAGE "we got an error, life is shit"
 
 void gi_marshalling_tests_gerror(GError **error);
 void gi_marshalling_tests_gerror_array_in(gint *in_ints, GError **error);
+void gi_marshalling_tests_gerror_out(GError **error, gchar **debug);
+void gi_marshalling_tests_gerror_out_transfer_none(GError **err, const gchar **debug);
+GError *gi_marshalling_tests_gerror_return(void);
+
+/* GParamSpec */
+GParamSpec *gi_marshalling_tests_param_spec_return();
+void gi_marshalling_tests_param_spec_out(GParamSpec **param);
 
 /* Overrides */
 
@@ -794,12 +994,12 @@ typedef struct _GIMarshallingTestsOverridesObject GIMarshallingTestsOverridesObj
 
 struct _GIMarshallingTestsOverridesObjectClass
 {
-	GObjectClass parent_class;
+    GObjectClass parent_class;
 };
 
 struct _GIMarshallingTestsOverridesObject
 {
-	GObject parent_instance;
+    GObject parent_instance;
 
     glong long_;
 };
@@ -810,7 +1010,44 @@ GIMarshallingTestsOverridesObject *gi_marshalling_tests_overrides_object_new (vo
 
 glong gi_marshalling_tests_overrides_object_method (GIMarshallingTestsOverridesObject *object);
 
-
 GIMarshallingTestsOverridesObject *gi_marshalling_tests_overrides_object_returnv (void);
 
+/* Properties Object */
+
+#define GI_MARSHALLING_TESTS_TYPE_PROPERTIES_OBJECT (gi_marshalling_tests_properties_object_get_type ())
+#define GI_MARSHALLING_TESTS_PROPERTIES_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GI_MARSHALLING_TESTS_TYPE_PROPERTIES_OBJECT, GIMarshallingTestsPropertiesObject))
+#define GI_MARSHALLING_TESTS_PROPERTIES_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GI_MARSHALLING_TESTS_TYPE_PROPERTIES_OBJECT, GIMarshallingTestsPropertiesObjectClass))
+#define GI_MARSHALLING_TESTS_IS_PROPERTIES_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GI_MARSHALLING_TESTS_TYPE_PROPERTIES_OBJECT))
+#define GI_MARSHALLING_TESTS_IS_PROPERTIES_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GI_MARSHALLING_TESTS_TYPE_PROPERTIES_OBJECT))
+#define GI_MARSHALLING_TESTS_PROPERTIES_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GI_MARSHALLING_TESTS_TYPE_PROPERTIES_OBJECT, GIMarshallingTestsPropertiesObjectClass))
+
+typedef struct _GIMarshallingTestsPropertiesObject GIMarshallingTestsPropertiesObject;
+typedef struct _GIMarshallingTestsPropertiesObjectClass GIMarshallingTestsPropertiesObjectClass;
+
+struct _GIMarshallingTestsPropertiesObject {
+    GObject parent_instance;
+
+    gboolean some_boolean;
+    gchar some_char;
+    guchar some_uchar;
+    gint some_int;
+    guint some_uint;
+    glong some_long;
+    gulong some_ulong;
+    gint64 some_int64;
+    guint64 some_uint64;
+    gfloat some_float;
+    gdouble some_double;
+    gchar **some_strv;
+    GIMarshallingTestsBoxedStruct* some_boxed_struct; 
+};
+
+struct _GIMarshallingTestsPropertiesObjectClass {
+    GObjectClass parent_class;
+};
+
+GType gi_marshalling_tests_properties_object_get_type (void) G_GNUC_CONST;
+
+GIMarshallingTestsPropertiesObject *gi_marshalling_tests_properties_object_new (void);
+
 #endif /* _GI_MARSHALLING_TESTS_H_ */
